@@ -65,7 +65,7 @@ function display_result(&$tag) {
     $commandpass = "";
     if (isset($samma_conf["commandpass"]) === TRUE && 
               $samma_conf["commandpass"] != "") {
-        $commandpass = htmlspecialchars($samma_conf["commandpass"]);
+        $commandpass = escape_html($samma_conf["commandpass"]);
     }
     $tag["<<COMMANDPASS>>"] = $commandpass;
 
@@ -93,7 +93,7 @@ function display_result(&$tag) {
     $encryptiontmpdir = "";
     if (isset($samma_conf["encryptiontmpdir"]) === TRUE && 
               $samma_conf["encryptiontmpdir"] != "") {
-        $encryptiontmpdir = htmlspecialchars($samma_conf["encryptiontmpdir"]);
+        $encryptiontmpdir = escape_html($samma_conf["encryptiontmpdir"]);
     }
     $tag["<<ENCRYPTIONTMPDIR>>"] = $encryptiontmpdir;
 
@@ -101,7 +101,7 @@ function display_result(&$tag) {
     $zipcommand = "";
     if (isset($samma_conf["zipcommand"]) === TRUE && 
               $samma_conf["zipcommand"] != "") {
-        $zipcommand = htmlspecialchars($samma_conf["zipcommand"]);
+        $zipcommand = escape_html($samma_conf["zipcommand"]);
     }
     $tag["<<ZIPCOMMAND>>"] = $zipcommand;
 
@@ -109,7 +109,7 @@ function display_result(&$tag) {
     $zipcommandopt = "";
     if (isset($samma_conf["zipcommandopt"]) === TRUE && 
               $samma_conf["zipcommandopt"] != "") {
-        $zipcommandopt = htmlspecialchars($samma_conf["zipcommandopt"]);
+        $zipcommandopt = escape_html($samma_conf["zipcommandopt"]);
     }
     $tag["<<ZIPCOMMANDOPT>>"] = $zipcommandopt;
 
@@ -122,7 +122,7 @@ function display_result(&$tag) {
                   $samma_conf["senderdb"] != "") {
             $send = explode(":", $samma_conf["senderdb"], 2);
             $type = $send[0];
-            $s_file = htmlspecialchars($send[1]);
+            $s_file = escape_html($send[1]);
         }
         $selected = "";
         /* פ */
@@ -143,7 +143,7 @@ function display_result(&$tag) {
                   $samma_conf["rcptdb"] != "") {
             $rcpt = explode(":", $samma_conf["rcptdb"], 2);
             $type = $rcpt[0];
-            $r_file = htmlspecialchars($rcpt[1]);
+            $r_file = escape_html($rcpt[1]);
         }
         $selected = "";
         /* פ */
@@ -159,7 +159,7 @@ function display_result(&$tag) {
     $templatepath = "";
     if (isset($samma_conf["templatepath"]) === TRUE && 
               $samma_conf["templatepath"] != "") {
-        $templatepath = htmlspecialchars($samma_conf["templatepath"]);
+        $templatepath = escape_html($samma_conf["templatepath"]);
     }
     $tag["<<TEMPLATEPATH>>"] = $templatepath;
 
@@ -167,7 +167,7 @@ function display_result(&$tag) {
     $sendmailcommand = "";
     if (isset($samma_conf["sendmailcommand"]) === TRUE && 
               $samma_conf["sendmailcommand"] != "") {
-        $sendmailcommand = htmlspecialchars($samma_conf["sendmailcommand"]);
+        $sendmailcommand = escape_html($samma_conf["sendmailcommand"]);
     }
     $tag["<<SENDMAILCOMMAND>>"] = $sendmailcommand;
 
@@ -175,7 +175,7 @@ function display_result(&$tag) {
     $zipfilename = "";
     if (isset($samma_conf["zipfilename"]) === TRUE && 
               $samma_conf["zipfilename"] != "") {
-        $zipfilename = htmlspecialchars($samma_conf["zipfilename"]);
+        $zipfilename = escape_html($samma_conf["zipfilename"]);
     }
     $tag["<<ZIPFILENAME>>"] = $zipfilename;
 
@@ -183,7 +183,7 @@ function display_result(&$tag) {
     $mailsavetmpdir = "";
     if (isset($samma_conf["mailsavetmpdir"]) === TRUE && 
               $samma_conf["mailsavetmpdir"] != "") {
-        $mailsavetmpdir = htmlspecialchars($samma_conf["mailsavetmpdir"]);
+        $mailsavetmpdir = escape_html($samma_conf["mailsavetmpdir"]);
     }
     $tag["<<MAILSAVETMPDIR>>"] = $mailsavetmpdir;
 
@@ -191,7 +191,7 @@ function display_result(&$tag) {
     $passwordlength = "";
     if (isset($samma_conf["passwordlength"]) === TRUE && 
               $samma_conf["passwordlength"] != "") {
-        $passwordlength = htmlspecialchars($samma_conf["passwordlength"]);
+        $passwordlength = escape_html($samma_conf["passwordlength"]);
     }
     $tag["<<PASSWORDLENGTH>>"] = $passwordlength;
 
@@ -232,7 +232,7 @@ function display_result(&$tag) {
     $defaultpassword = "";
     if (isset($samma_conf["defaultpassword"]) === TRUE && 
               $samma_conf["defaultpassword"] != "") {
-        $defaultpassword = htmlspecialchars($samma_conf["defaultpassword"]);
+        $defaultpassword = escape_html($samma_conf["defaultpassword"]);
     }
     $tag["<<DEFAULTPASSWORD>>"] = $defaultpassword;
 
@@ -262,8 +262,8 @@ function display_result(&$tag) {
         /* IPȥݡȤڤʬ */
         $serverdata = explode(":", $uri[1]);
         /* Ǽ(ݡȤΡ/פ) */
-        $ldapserver = htmlspecialchars($serverdata[0]);
-        $ldapport = htmlspecialchars(rtrim($serverdata[1], "/"));
+        $ldapserver = escape_html($serverdata[0]);
+        $ldapport = escape_html(rtrim($serverdata[1], "/"));
     }
     $tag["<<LDAPSERVER>>"] = $ldapserver;
     $tag["<<LDAPPORT>>"] = $ldapport;
@@ -272,7 +272,7 @@ function display_result(&$tag) {
     $ldapbasedn = "";
     if (isset($samma_conf["ldapbasedn"]) === TRUE && 
               $samma_conf["ldapbasedn"] != "") {
-        $ldapbasedn = htmlspecialchars($samma_conf["ldapbasedn"]);
+        $ldapbasedn = escape_html($samma_conf["ldapbasedn"]);
     }
     $tag["<<LDAPBASEDN>>"] = $ldapbasedn;
 
@@ -280,7 +280,7 @@ function display_result(&$tag) {
     $ldapbinddn = "";
     if (isset($samma_conf["ldapbinddn"]) === TRUE && 
               $samma_conf["ldapbinddn"] != "") {
-        $ldapbinddn = htmlspecialchars($samma_conf["ldapbinddn"]);
+        $ldapbinddn = escape_html($samma_conf["ldapbinddn"]);
     }
     $tag["<<LDAPBINDDN>>"] = $ldapbinddn;
 
@@ -288,7 +288,7 @@ function display_result(&$tag) {
     $ldapbindpassword = "";
     if (isset($samma_conf["ldapbindpassword"]) === TRUE && 
               $samma_conf["ldapbindpassword"] != "") {
-        $ldapbindpassword = htmlspecialchars($samma_conf["ldapbindpassword"]);
+        $ldapbindpassword = escape_html($samma_conf["ldapbindpassword"]);
     }
     $tag["<<LDAPBINDPASSWORD>>"] = $ldapbindpassword;
 
@@ -296,7 +296,7 @@ function display_result(&$tag) {
     $ldapfilter = "";
     if (isset($samma_conf["ldapfilter"]) === TRUE && 
               $samma_conf["ldapfilter"] != "") {
-        $ldapfilter = htmlspecialchars($samma_conf["ldapfilter"]);
+        $ldapfilter = escape_html($samma_conf["ldapfilter"]);
     }
     $tag["<<LDAPFILTER>>"] = $ldapfilter;
 
