@@ -92,7 +92,7 @@ function hidden_result(&$tag) {
 
     $hidden = "";
     foreach($hiddendata as $hidkey => $hidval) {
-        $hidval = htmlspecialchars($hidval);
+        $hidval = escape_html($hidval);
         $hidden .= "<input type=\"hidden\" name=\"$hidkey\" value=\"$hidval\">";
     }
 
@@ -150,7 +150,7 @@ function print_result(&$looptag)
         }
 
         /*  */
-        $domain = htmlspecialchars($domain);
+        $domain = escape_html($domain);
         $cnv_key = str_replace("'", "\'", $key);
 
         $looptag[$domain_count]["<<KEY>>"] = $key;
@@ -199,7 +199,7 @@ if ($ret === FALSE) {
 
 /* å */
 if (isset($_POST["msg"]) === TRUE) {
-    $err_msg = htmlspecialchars($_POST["msg"]);
+    $err_msg = escape_html($_POST["msg"]);
 }
 
 /***********************************************************
@@ -249,7 +249,7 @@ if ($ret !== TRUE) {
 $user = $ldapdata[0]["uid"][0];
 
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);
+$dispusr = escape_html($ldapdata[0][$dispusr][0]);
 
 /* եǼ */
 $form_name = $_POST["form_name"];
@@ -284,6 +284,7 @@ if (isset($_POST["new_add"]) === TRUE) {
                 $suc_msg = "" . $suc_msg;
                 result_log(OPERATION . ":OK:" . $suc_msg);
                 $err_msg .= "<br>" . $suc_msg;
+                $del_list = array();
             }
         /* 顼ϥƥ२顼 */
         } elseif ($ret!== LDAP_OK) {
@@ -294,6 +295,7 @@ if (isset($_POST["new_add"]) === TRUE) {
         } else {
             $err_msg = "" . $suc_msg;
             result_log(OPERATION . ":OK:" . $err_msg);
+            $del_list = array();
         }
 
     }
