@@ -64,13 +64,13 @@ function set_tag_data(&$tag) {
     global $add_data;
 
     /* 桼̾ */
-    $user = htmlspecialchars($dispusr);
+    $user = escape_html($dispusr);
     $tag["<<USER>>"] = $user;
 
     /* ɥᥤ̾ */
     $domain = "";
     if (isset($add_data["domain"]) === TRUE) {
-        $domain = htmlspecialchars($add_data["domain"]);
+        $domain = escape_html($add_data["domain"]);
     }
     $tag["<<DOMAIN>>"] = $domain;
 
@@ -90,7 +90,7 @@ function set_tag_data(&$tag) {
     /* ̥ѥ */
     $indivipass = "";
     if (isset($add_data["indivipass"]) === TRUE) {
-        $indivipass = htmlspecialchars($add_data["indivipass"]);
+        $indivipass = escape_html($add_data["indivipass"]);
     }
     $tag["<<INDIVIPASS>>"] = $indivipass;
 
@@ -147,7 +147,7 @@ if ($ret === FALSE) {
 }
 
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);
+$dispusr = escape_html($ldapdata[0][$dispusr][0]);
 
 /* ݻͼ */
 $del_list = "";
@@ -199,7 +199,7 @@ if (isset($_POST["add"]) === TRUE) {
 /* 󥻥 */
 } elseif (isset($_POST["cancel"]) === TRUE) {
     /* ɲò̤ */
-    dgp_location("index.php", $del_list);
+    dgp_location("index.php");
     exit (0);
 
 }
